module Types = Types
module Config = Config

module Html_fragment_json = Html_fragment_json
(** @canonical Odoc_html.Html_fragment_json *)

module Html_page = Html_page
(** @canonical Odoc_html.Html_page *)

module Generator = Generator
module Link = Link
module Json = Odoc_utils.Json
module Sidebar = Sidebar
